@@ -141,7 +141,7 @@ def mmm( sky_vector,
     minimm = minimm -1               #Highest value reject at lower end of vector
 
     # Compute mean and sigma (from the first pass).
-    medianIndex = np.int(np.floor((minimm+maximm+1)/2))
+    medianIndex = int(np.floor((minimm+maximm+1)/2))
 
     skymed = 0.5*sky[medianIndex] + \
       0.5*sky[medianIndex + 1] #median 
@@ -269,8 +269,8 @@ def mmm( sky_vector,
     
         center = (minimm + 1 + maximm)/2.
         side = np.round(0.2*(maximm-minimm))/2.  + 0.25
-        j = np.int(np.round(center-side))
-        k = np.int(np.round(center+side))
+        j = int(np.round(center-side))
+        k = int(np.round(center+side))
 
         #  In case  the data has a large number of of the same (quantized) 
         #  intensity, expand the range until both limiting values differ from the 
